@@ -929,7 +929,8 @@ L<constant>, L<enum>, L<Class::Class>, L<Class::ArrayObjects>
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
