@@ -132,7 +132,8 @@ L<Chj::xopen>, L<Chj::IO::SysFile>, L<Chj::xsysopen>
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
