@@ -16,7 +16,8 @@ A simple tempdir procedure, without auto cleanup.
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
